@@ -76,7 +76,7 @@ only convert features between a subset of formats.
 
 """
 
-__version__ = '2.0.4'
+__version__ = '2.0.5'
 
 from collections import OrderedDict
 import re
@@ -1374,7 +1374,7 @@ class Insert(object):
         Mostly complete, excepting 'attribute'.
 
         """
-        options = Insert.KIND_OPTIONS.get(self.kind, [])
+        options = list(Insert.KIND_OPTIONS.get(self.kind, []))
         if scriptable:
             if self.kind == 'var':
                 options += scriptable.variables.keys()
@@ -1538,6 +1538,12 @@ class BlockType(BaseBlockType):
 
     """
 
+    def __getstate__(self):
+        """lambda functions are not pickleable so drop them."""
+        copy = self.__dict__.copy()
+        copy['_workaround'] = None
+        return copy
+
     def __init__(self, pbt):
         if isinstance(pbt, basestring):
             raise ValueError("Invalid argument. Did you mean `BlockType.get`?")
@@ -1946,6 +1952,8 @@ class Script(object):
     # Pretend to be a list
 
     def __getattr__(self, name):
+        if name.startswith('__') and name.endswith('__'):
+            return super(Script, self).__getattr__(name)
         return getattr(self.blocks, name)
 
     def __iter__(self):
@@ -2069,7 +2077,7 @@ class Costume(object):
     def __getattr__(self, name):
         if name in ('width', 'height', 'size'):
             return getattr(self.image, name)
-        raise AttributeError, "%r object has no attribute %r" % (self, name)
+        return super(Costume, self).__getattr__(name)
 
 
 class Image(object):
@@ -2111,6 +2119,21 @@ class Image(object):
             self._contents = contents
             self._format = Image.image_format(format)
 
+    def __getstate__(self):
+        if isinstance(self._pil_image, PIL.Image.Image):
+            copy = self.__dict__.copy()
+            copy['_pil_image'] = {
+                'data': self._pil_image.tobytes(),
+                'size': self._pil_image.size,
+                'mode': self._pil_image.mode}
+            return copy
+        return self.__dict__
+
+    def __setstate__(self, data):
+        self.__dict__.update(data)
+        if self._pil_image:
+            self._pil_image = PIL.Image.frombytes(**self._pil_image)
+
     # Properties
 
     @property
